AsyncHttpRangeReaderError

Enum AsyncHttpRangeReaderError 

#[non_exhaustive]
pub enum AsyncHttpRangeReaderError { HttpRangeRequestUnsupported, HttpError(Arc<Error>), TransportError(Arc<Error>), IoError(Arc<Error>), ContentRangeMissing, ContentLengthMissing, MemoryMapError(Arc<Error>), ContentRangeParser(String), RangeMismatch { expected_start: u64, expected_end_inclusive: u64, expected_complete_length: usize, actual_start: u64, actual_end_inclusive: u64, actual_complete_length: u64, }, ResponseTooLong { expected: u64, }, ResponseTooShort { expected: u64, actual: u64, }, }
Error type used for crate::AsyncHttpRangeReader

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


HttpRangeRequestUnsupported

The server does not support range requests



HttpError(Arc<Error>)

Other HTTP error



TransportError(Arc<Error>)

An error occurred during transport



IoError(Arc<Error>)

An IO error occurred



ContentRangeMissing

Content-Range header is missing from response



ContentLengthMissing

Content-Length header is missing from response



MemoryMapError(Arc<Error>)

Memory mapping the file failed



ContentRangeParser(String)

Error from http-content-range



RangeMismatch

The server returned an invalid range response

Fields

expected_start: u64
expected_end_inclusive: u64
expected_complete_length: usize
actual_start: u64
actual_end_inclusive: u64
actual_complete_length: u64


ResponseTooLong

The server returned more bytes than the range request asked for

Fields

expected: u64


ResponseTooShort

The server returned fewer bytes than the range request asked for

Fields

expected: u64
actual: u64